==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/SaveI6InteractionSyncInteractionForEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveI6InteractionSyncInteractionForEvaluationPlan] (
	@VCC					VARCHAR(50) = NULL,
	@InteractionId			VARCHAR(250) = NULL,
	@OldSection				INT = NULL,
	@OldPart				INT = NULL,
	@NewSection				INT = NULL,
	@NewPart				INT = NULL,
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@DurationTime			INT = NULL,
	@Format					VARCHAR(10) = NULL,
	@AgentId				VARCHAR(50) = NULL,
	@AgentName				VARCHAR(100) = NULL,
	@Campaign				VARCHAR(100) = NULL,
	@Origin					VARCHAR(25) = NULL,
	@Category1				VARCHAR(100) = NULL,
	@Category2				VARCHAR(100) = NULL,
	@Category3				VARCHAR(100) = NULL,
	@Description			VARCHAR(100) = NULL,
	@ContactId				VARCHAR(50) = NULL,
	@ContactName			VARCHAR(300) = NULL,
	@ContactAddress			VARCHAR(300) = NULL,
	@EvaluationPlanId		VARCHAR(50) = NULL
) AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR UNA INTERACCION DE I6
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- DECLARAMOS UN CURSOR PARA RECORRER PLANES
        DECLARE RECURRENT_CURSOR CURSOR 
        LOCAL STATIC READ_ONLY FORWARD_ONLY
        FOR 
        	-- SELECCIONAMOS LOS PLANES DONDE ESTA REGISTRADA LA INTERACCION
			SELECT DISTINCT [IdEvaluationPlan]
				FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				INNER JOIN[dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = IEP.[Instance]
						AND EP.[ID] = IEP.[IdEvaluationPlan]
				WHERE IEP.[Instance] = @VCC
					AND IEP.[IdInteraction] = @InteractionId
					AND IEP.[NeedI6Update] = 1
					AND (
						IEP.[IdEvaluationPlan] = @EvaluationPlanId
						OR 
						@EvaluationPlanId IS NULL
					)
					AND EP.[Status] <= 6

		-- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS RECORRIENDO
        DECLARE @CURRENT_EVALUATION_PLAN VARCHAR(50) = ''

		-- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
        OPEN RECURRENT_CURSOR

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_EVALUATION_PLAN
        WHILE @@FETCH_STATUS = 0
        BEGIN 
			-- PARA EL PLAN ACTUAL BUSCAMOS SI EXISTE INTERACCION CON EL OLD-SECTION Y OLD-PART CORRESPONDIENTE
			DECLARE @EXISTS_IEP BIT = 0
			SELECT @EXISTS_IEP = IIF(IEP.[IdInteraction] IS NOT NULL, CAST(1 AS BIT), CAST(0 AS BIT))
				FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK) 
				WHERE IEP.[Instance] = @VCC
					AND IEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
					AND IEP.[IdInteraction] = @InteractionId
					AND IEP.[InteractionSection] = @OldSection
					AND IEP.[InteractionPart] = @OldPart

			-- SI LA INTERACCION-SECTION-PART EXISTE, LA ACTUALIZAMOS
			IF @EXISTS_IEP = 1
			BEGIN
				-- ACTUALIZAMOS LA INTERACCION
				UPDATE [dbo].[InteractionEvaluationPlan] 
					SET [IdCampaign] = @Campaign,
						[InteractionSection] = @NewSection,
						[InteractionPart] = @NewPart,
						[IdAgent] = @AgentId,
						[AgentName] = @AgentName,
						[InteractionDateStart] = @StartDate,
						[InteractionDateEnd] = @EndDate,
						[InteractionOrigin] = @Origin,
						[InteractionFormat] = @Format,
						[ManagementResult] = @Category1 + @Category2 + @Category3 + @Description, 
						[ContactId] = @ContactId,
						[ContactName] = @ContactName,
						[ContactAddress] = @ContactAddress,
						[NeedI6Update] = 0,
						[LastModifiedByUserId] = 'system',
						[LastModifiedDate] = GETUTCDATE(),
						[TimeStamp] = GETUTCDATE()
					WHERE [Instance] = @VCC
						AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
						AND [IdInteraction] = @InteractionId
						AND [InteractionSection] = @OldSection
						AND [InteractionPart] = @OldPart
						AND [NeedI6Update] = 1
			END
			-- SI LA INTERACCION-SECTION-PART NO EXISTE, LA INSERTAMOS
			ELSE
			BEGIN
				-- INSERTAMOS LA INTERACCION  SELECT * FROM [dbo].[InteractionEvaluationPlan]
				INSERT INTO [dbo].[InteractionEvaluationPlan] (
					[Instance], [IdEvaluationPlan], [InteractionType], [IdCampaign], [IdInteraction], 
					[InteractionSection], [InteractionPart], [IdAgent], [AgentName], [InteractionDateStart], 
					[InteractionDateEnd], [InteractionDuration], [InteractionOrigin], [InteractionFormat], [ManagementResult], 
					[ContactId], [ContactName], [ContactAddress], [NeedI6Update], [CreatedByUserId], 
					[CreatedDate], [TimeStamp]
				) VALUES (
					@VCC, @CURRENT_EVALUATION_PLAN, 'CALL', @Campaign, @InteractionId, 
					@NewSection, @NewPart, @AgentId, @AgentName, @StartDate, 
					@EndDate, @DurationTime, @Origin, @Format, @Category1 + @Category2 + @Category3 + @Description, 
					@ContactId, @ContactName, @ContactAddress, CAST(0 AS BIT), 'system', 
					GETUTCDATE(), GETUTCDATE()
				)
			END

			-- DECLARAMOS UN CURSOR PARA RECORRER AUDITORES
			DECLARE RECURRENT_CURSOR_02 CURSOR 
			LOCAL STATIC READ_ONLY FORWARD_ONLY
			FOR 
        		-- SELECCIONAMOS LOS AUDITORES QUE TIENEN ASIGNADA LA INTERACCION
				SELECT AEP.[IdAuditor]
					FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
					WHERE AEP.[Instance] = @VCC 
						AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
						AND AEP.[IdInteraction] = @InteractionId

			-- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS RECORRIENDO
			DECLARE @CURRENT_AUDITOR VARCHAR(50) = ''

			-- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
			OPEN RECURRENT_CURSOR_02

			FETCH NEXT FROM RECURRENT_CURSOR_02 INTO @CURRENT_AUDITOR
			WHILE @@FETCH_STATUS = 0
			BEGIN 
				-- PARA EL PLAN ACTUAL BUSCAMOS SI EXISTE INTERACCION CON EL FOLDER CORRESPONDIENTE
				DECLARE @EXISTS_AEP BIT = 0
				SELECT @EXISTS_AEP = IIF(AEP.[IdInteraction] IS NOT NULL, CAST(1 AS BIT), CAST(0 AS BIT))
					FROM [dbo].[InteractionEvaluationPlan] AEP (NOLOCK) 
					WHERE AEP.[Instance] = @VCC
						AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
						AND AEP.[IdInteraction] = @InteractionId

				-- SI LA INTERACCION-FOLDER EXISTE, LA ACTUALIZAMOS
				IF @EXISTS_AEP = 1
				BEGIN
					-- ACTUALIZAMOS EL REGISTRO DE AUDITOREVALUATIONPLAN
					UPDATE [dbo].[AuditorEvaluationPlan] 
						SET [IdCampaign] = @Campaign,
							[IdAgent] = @AgentId,
							[InteractionFormat] = @Format,
							[ManagementResult] = @Category1 + @Category2 + @Category3 + @Description,
							[ContactId] = @ContactId,
							[ContactName] = @ContactName,
							[ContactAddress] = @ContactAddress,
							[LastModifiedByUserId] = 'system',
							[LastModifiedDate] = GETUTCDATE(),
							[TimeStamp] = GETUTCDATE()
						WHERE [Instance] = @VCC
							AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
							AND [IdInteraction] = @InteractionId
							AND [IdAuditor] = @CURRENT_AUDITOR
							AND [Completed] = 0
				END
				ELSE
				BEGIN
					-- INSERTAMOS EL REGISTRO A AUDITOREVALUATIONPLA
					INSERT INTO [dbo].[AuditorEvaluationPlan] (
						[Instance], [IdEvaluationPlan], [IdAuditor], [IdInteraction], [Completed], 
						[Score], [IdCampaign], [IdAgent], [InteractionDate], [InteractionType], 
						[InteractionDuration], [InteractionOrigin], [InteractionDateEnd], [ManagementResult], [ContactId], 
						[ContactName], [ContactAddress], [Status], [StatusDescription],
						[CreatedByUserId], [CreatedDate], [TimeStamp]
					) VALUES (
						@VCC, @CURRENT_EVALUATION_PLAN, @CURRENT_AUDITOR, @InteractionId, 0,
						0, @Campaign, @AgentId, @StartDate, 'CALL', 
						@DurationTime, @Origin, @EndDate, @Category1 + @Category2 + @Category3 + @Description, @ContactId,
						@ContactName, @ContactAddress, 1, 'NEW',
						'system', GETUTCDATE(), GETUTCDATE()
					)
				END

				FETCH NEXT FROM RECURRENT_CURSOR_02 INTO @CURRENT_AUDITOR
			END
			CLOSE RECURRENT_CURSOR_02
			DEALLOCATE RECURRENT_CURSOR_02

			FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_EVALUATION_PLAN
        END
        CLOSE RECURRENT_CURSOR
        DEALLOCATE RECURRENT_CURSOR

		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.4.4_database.tar.gz: database/mssql/procedures/SaveI6InteractionSyncInteractionForEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveI6InteractionSyncInteractionForEvaluationPlan] (
	@VCC					VARCHAR(50) = NULL,
	@InteractionId			VARCHAR(250) = NULL,
	@OldSection				INT = NULL,
	@OldPart				INT = NULL,
	@NewSection				INT = NULL,
	@NewPart				INT = NULL,
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@DurationTime			INT = NULL,
	@Format					VARCHAR(10) = NULL,
	@AgentId				VARCHAR(50) = NULL,
	@AgentName				VARCHAR(100) = NULL,
	@Campaign				VARCHAR(100) = NULL,
	@Origin					VARCHAR(25) = NULL,
	@Category1				VARCHAR(100) = NULL,
	@Category2				VARCHAR(100) = NULL,
	@Category3				VARCHAR(100) = NULL,
	@Description			VARCHAR(100) = NULL,
	@ContactId				VARCHAR(50) = NULL,
	@ContactName			VARCHAR(300) = NULL,
	@ContactAddress			VARCHAR(300) = NULL,
	@EvaluationPlanId		VARCHAR(50) = NULL,
	@Ender				    VARCHAR(300) = NULL,
	@Ticket					VARCHAR(300) = NULL
) AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR UNA INTERACCION DE I6
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- DECLARAMOS UN CURSOR PARA RECORRER PLANES
        DECLARE RECURRENT_CURSOR CURSOR 
        LOCAL STATIC READ_ONLY FORWARD_ONLY
        FOR 
        	-- SELECCIONAMOS LOS PLANES DONDE ESTA REGISTRADA LA INTERACCION
			SELECT DISTINCT [IdEvaluationPlan]
				FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				INNER JOIN[dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = IEP.[Instance]
						AND EP.[ID] = IEP.[IdEvaluationPlan]
				WHERE IEP.[Instance] = @VCC
					AND IEP.[IdInteraction] = @InteractionId
					AND IEP.[NeedI6Update] = 1
					AND (
						IEP.[IdEvaluationPlan] = @EvaluationPlanId
						OR 
						@EvaluationPlanId IS NULL
					)
					AND EP.[Status] <= 6

		-- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS RECORRIENDO
        DECLARE @CURRENT_EVALUATION_PLAN VARCHAR(50) = ''

		-- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
        OPEN RECURRENT_CURSOR

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_EVALUATION_PLAN
        WHILE @@FETCH_STATUS = 0
        BEGIN 
			-- PARA EL PLAN ACTUAL BUSCAMOS SI EXISTE INTERACCION CON EL OLD-SECTION Y OLD-PART CORRESPONDIENTE
			DECLARE @EXISTS_IEP BIT = 0
			SELECT @EXISTS_IEP = IIF(IEP.[IdInteraction] IS NOT NULL, CAST(1 AS BIT), CAST(0 AS BIT))
				FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK) 
				WHERE IEP.[Instance] = @VCC
					AND IEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
					AND IEP.[IdInteraction] = @InteractionId
					AND IEP.[InteractionSection] = @OldSection
					AND IEP.[InteractionPart] = @OldPart

			-- SI LA INTERACCION-SECTION-PART EXISTE, LA ACTUALIZAMOS
			IF @EXISTS_IEP = 1
			BEGIN
				-- ACTUALIZAMOS LA INTERACCION
				UPDATE [dbo].[InteractionEvaluationPlan] 
					SET [IdCampaign] = @Campaign,
						[InteractionSection] = @NewSection,
						[InteractionPart] = @NewPart,
						[IdAgent] = @AgentId,
						[AgentName] = @AgentName,
						[InteractionDateStart] = @StartDate,
						[InteractionDateEnd] = @EndDate,
						[InteractionOrigin] = @Origin,
						[InteractionFormat] = @Format,
						[ManagementResult] = @Category1 + @Category2 + @Category3 + @Description, 
						[ContactId] = @ContactId,
						[ContactName] = @ContactName,
						[ContactAddress] = @ContactAddress,
						[NeedI6Update] = 0,
						[LastModifiedByUserId] = 'system',
						[LastModifiedDate] = GETUTCDATE(),
						[TimeStamp] = GETUTCDATE(),
						[Ender] = @Ender,
						[Ticket] = @Ticket
					WHERE [Instance] = @VCC
						AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
						AND [IdInteraction] = @InteractionId
						AND [InteractionSection] = @OldSection
						AND [InteractionPart] = @OldPart
						AND [NeedI6Update] = 1
			END
			-- SI LA INTERACCION-SECTION-PART NO EXISTE, LA INSERTAMOS
			ELSE
			BEGIN
				-- INSERTAMOS LA INTERACCION  SELECT * FROM [dbo].[InteractionEvaluationPlan]
				INSERT INTO [dbo].[InteractionEvaluationPlan] (
					[Instance], [IdEvaluationPlan], [InteractionType], [IdCampaign], [IdInteraction], 
					[InteractionSection], [InteractionPart], [IdAgent], [AgentName], [InteractionDateStart], 
					[InteractionDateEnd], [InteractionDuration], [InteractionOrigin], [InteractionFormat], [ManagementResult], 
					[ContactId], [ContactName], [ContactAddress], [NeedI6Update], [CreatedByUserId], 
					[CreatedDate], [TimeStamp], [Ender], [Ticket]
				) VALUES (
					@VCC, @CURRENT_EVALUATION_PLAN, 'CALL', @Campaign, @InteractionId, 
					@NewSection, @NewPart, @AgentId, @AgentName, @StartDate, 
					@EndDate, @DurationTime, @Origin, @Format, @Category1 + @Category2 + @Category3 + @Description, 
					@ContactId, @ContactName, @ContactAddress, CAST(0 AS BIT), 'system', 
					GETUTCDATE(), GETUTCDATE(), @Ender, @Ticket
				)
			END

			-- DECLARAMOS UN CURSOR PARA RECORRER AUDITORES
			DECLARE RECURRENT_CURSOR_02 CURSOR 
			LOCAL STATIC READ_ONLY FORWARD_ONLY
			FOR 
        		-- SELECCIONAMOS LOS AUDITORES QUE TIENEN ASIGNADA LA INTERACCION
				SELECT AEP.[IdAuditor]
					FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
					WHERE AEP.[Instance] = @VCC 
						AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
						AND AEP.[IdInteraction] = @InteractionId

			-- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS RECORRIENDO
			DECLARE @CURRENT_AUDITOR VARCHAR(50) = ''

			-- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
			OPEN RECURRENT_CURSOR_02

			FETCH NEXT FROM RECURRENT_CURSOR_02 INTO @CURRENT_AUDITOR
			WHILE @@FETCH_STATUS = 0
			BEGIN 
				-- PARA EL PLAN ACTUAL BUSCAMOS SI EXISTE INTERACCION CON EL FOLDER CORRESPONDIENTE
				DECLARE @EXISTS_AEP BIT = 0
				SELECT @EXISTS_AEP = IIF(AEP.[IdInteraction] IS NOT NULL, CAST(1 AS BIT), CAST(0 AS BIT))
					FROM [dbo].[InteractionEvaluationPlan] AEP (NOLOCK) 
					WHERE AEP.[Instance] = @VCC
						AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
						AND AEP.[IdInteraction] = @InteractionId

				-- SI LA INTERACCION-FOLDER EXISTE, LA ACTUALIZAMOS
				IF @EXISTS_AEP = 1
				BEGIN
					-- ACTUALIZAMOS EL REGISTRO DE AUDITOREVALUATIONPLAN
					UPDATE [dbo].[AuditorEvaluationPlan] 
						SET [IdCampaign] = @Campaign,
							[IdAgent] = @AgentId,
							[InteractionFormat] = @Format,
							[ManagementResult] = @Category1 + @Category2 + @Category3 + @Description,
							[ContactId] = @ContactId,
							[ContactName] = @ContactName,
							[ContactAddress] = @ContactAddress,
							[LastModifiedByUserId] = 'system',
							[LastModifiedDate] = GETUTCDATE(),
							[TimeStamp] = GETUTCDATE()
						WHERE [Instance] = @VCC
							AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN
							AND [IdInteraction] = @InteractionId
							AND [IdAuditor] = @CURRENT_AUDITOR
							AND [Completed] = 0
				END
				ELSE
				BEGIN
					-- INSERTAMOS EL REGISTRO A AUDITOREVALUATIONPLA
					INSERT INTO [dbo].[AuditorEvaluationPlan] (
						[Instance], [IdEvaluationPlan], [IdAuditor], [IdInteraction], [Completed], 
						[Score], [IdCampaign], [IdAgent], [InteractionDate], [InteractionType], 
						[InteractionDuration], [InteractionOrigin], [InteractionDateEnd], [ManagementResult], [ContactId], 
						[ContactName], [ContactAddress], [Status], [StatusDescription],
						[CreatedByUserId], [CreatedDate], [TimeStamp]
					) VALUES (
						@VCC, @CURRENT_EVALUATION_PLAN, @CURRENT_AUDITOR, @InteractionId, 0,
						0, @Campaign, @AgentId, @StartDate, 'CALL', 
						@DurationTime, @Origin, @EndDate, @Category1 + @Category2 + @Category3 + @Description, @ContactId,
						@ContactName, @ContactAddress, 1, 'NEW',
						'system', GETUTCDATE(), GETUTCDATE()
					)
				END

				FETCH NEXT FROM RECURRENT_CURSOR_02 INTO @CURRENT_AUDITOR
			END
			CLOSE RECURRENT_CURSOR_02
			DEALLOCATE RECURRENT_CURSOR_02

			FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_EVALUATION_PLAN
        END
        CLOSE RECURRENT_CURSOR
        DEALLOCATE RECURRENT_CURSOR

		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
